/*   gloSerialOLED Library -  gloCustomChar_UART

This sketch shows how to use the Seetron gloSerialOLED macros to
talk to a GLO-216 or GLO-416 serial OLED using an Arduino 
hardware serial port (UART). This program is meant for boards
like the Mega that have more than one hardware UART. 
Sharing the bootloader port is _not_ recommended. 

====================================================================
MACRO(S) DEMONSTRATED: 

gloRecallCustomChars 
gloSetCursor( col, row )
gloCustomChar( ccnum )
gloCreateChar( ccnum, patarray )

gloRecallCustomChars GLO- instructions to restore the custom-
character patterns from flash memory. This is the 'undo' 
instruction for gloCreateChar() below. 

gloSetCursor() GLO- instructions to set the 'cursor' (printing 
location) at col, row (where col is horizontal and row is vertical). 

gloCustomChar() GLO- instructions to display the 
specified custom character (0-15). 

gloCreateChar() GLO- instructions to set the specified 
custom character (0-15) to the pattern contained in an 
8-byte array.

====================================================================
Connections:
GLO +5 to Arduino +5V
GLO GND to Arduino GND
GLO SER to Arduino pin TX1
GLO SPOL jumper: Cut
____________
History:
1st Release 2 June 2014
(Tested under IDE version 1.5.6-r2 w/ Arduino MEGA 2560, Arduino UNO)
____________
More Info:
seetron.com or email tech@seetron.com
*/

// Include SoftwareSerial 
#include <SoftwareSerial.h>

// Include gloSerialOLED _and_ the 'streaming' template, which lets you combine 
// multiple print()s into a single line. This is required by the serial OLED macros. 
#include <gloSerialOLED.h>
gloStreamingTemplate

/* Initialize SoftwareSerial by naming the serial object, and
   specifying the output pin and serial polarity (SPOL).
   If the SPOL jumper on the GLO is intact, use "inverted."
   If SPOL is cut, use "noninverted." */

gloSoftSerialSetup( myOLED, 3, noninverted );

/* Cool custom-character artwork from the Arduino forum at 
   http://forum.arduino.cc/index.php/topic,54411.0.html 
   Since the GLO cust-char mechanisms are modeled after those
   used in text LCDs, bitmaps are interchangeable without mods. */   
  byte thumb1[8] = {B00100,B00011,B00100,B00011,B00100,B00011,B00010,B00001};
  byte thumb2[8] = {B00000,B00000,B00000,B00000,B00000,B00000,B00000,B00011};
  byte thumb3[8] = {B00000,B00000,B00000,B00000,B00000,B00000,B00001,B11110};
  byte thumb4[8] = {B00000,B01100,B10010,B10010,B10001,B01000,B11110,B00000};
  byte thumb5[8] = {B00010,B00010,B00010,B00010,B00010,B01110,B10000,B00000};
  byte thumb6[8] = {B00000,B00000,B00000,B00000,B00000,B10000,B01000,B00110};

//===================================================================
void setup() {
// Begin using the serial object created above.
  gloSoftSerialBegin( myOLED ) ;
  
// Allow 1/4 sec for the OLED to start up. 
  delay(250) ; 

// Clear the screen, set to the smallest font, show title and clean up 
// any previous changes to custom characters.
  myOLED << gloClear << gloFont_1w1h << "  Custom Chars  " << gloRecallCustomChars ;  

// Display all custom chars, 0-15. 
  for(byte i=0; i<16; i++){
  myOLED << gloCustomChar(i);  
  }

  delay(1500);   // Pause. 
  
// Load bitmaps from 'thumb' arrays above. 
  myOLED << gloCreateChar(0,thumb1) << gloCreateChar(1,thumb2) ;
  myOLED << gloCreateChar(2,thumb3) << gloCreateChar(3,thumb4) ;
  myOLED << gloCreateChar(4,thumb5) << gloCreateChar(5,thumb6) ;

  myOLED << gloClearScreen << gloFont_1w2h << " seetron.com" << gloFont_1w1h ;
  
// Display the artistic talent of Arduino forum user JO3RI... 
  myOLED << gloSetCursor(13,1) << gloCustomChar(0) ;
  myOLED << gloSetCursor(13,0) << gloCustomChar(1) ;
  myOLED << gloSetCursor(14,1) << gloCustomChar(2) ;
  myOLED << gloSetCursor(14,0) << gloCustomChar(3) ;
  myOLED << gloSetCursor(15,1) << gloCustomChar(4) ;
  myOLED << gloSetCursor(15,0) << gloCustomChar(5) ;

  delay(1500);   // Pause. 

//Display the custom chars again--note changes.
  myOLED << gloClear << "    -Changed-   " ;  

  for(byte i=0; i<16; i++){
  myOLED << gloCustomChar(i);  
  }

  delay(1500);   // Pause. 

//Display the custom chars again AFTER recalling from flash mem.
  myOLED << gloRecallCustomChars << gloClear << "    -Restored-  " ;  

  for(byte i=0; i<16; i++){
  myOLED << gloCustomChar(i);  
  }
}

//===================================================================
/*   */ 
void loop() {

}
