/*   gloSerialOLED Library -  HelloWorld_UART

This program shows how to use the Seetron gloSerialOLED macros to
talk to a GLO-216 or GLO-416 serial OLED using an Arduino 
hardware serial port (UART). This program is meant for boards
like the Mega that have more than one hardware UART. 
Sharing the bootloader port is _not_ recommended. 

This program will run on both -216 and -416 models, but only
uses the first two lines.
____________
Connections:
GLO +5 to Arduino +5V
GLO GND to Arduino GND
GLO SER to Arduino pin TX1
GLO SPOL jumper: Cut
____________
History:
1st Release 2 June 2014
(Tested under IDE version 1.5.6-r2 w/ Arduino MEGA 2560, Arduino DUE)
____________
More Info:
seetron.com  tech@seetron.com */

// Include gloSerialOLED _and_ the 'streaming' template, which lets you combine 
// multiple print()s into a single line. This is required by the serial OLED macros.  
#include <gloSerialOLED.h>
template<class T> inline Print &operator <<(Print &obj, T arg) { obj.print(arg); return obj; }

// ============================================================
void setup() {
// Init the serial port for 9600bps.
  Serial1.begin(9600);

// Now funnel data into myOLED with the 'streaming' operator <<
// The gloSerialOLED header includes friendly names for the
// OLED's internal instructions, letting you use names like
// gloClear instead of "\x0c" for 'clear screen.' The
// font settings are named for their width and height, so
// gloFont_1w2h means "1x width and 2x height."

  Serial1 << gloClear << gloFont_1w2h << " Hello Arduino!";

// After a short pause, clear the screen and change the font.
  delay(1000) ;
  Serial1 << gloClear << gloFont_2w2h ;
}

// ============================================================
void loop() {
// Set position to the 1st character (top-left) of the screen
// and print the value of the Arduino millisecond timer 
// divided by 200. (Provides a changing # to look at.)
    Serial1 << gloHome << ( millis() / 200 ) ; 
}
