/*   gloSerialOLED Library -  gloStartupScreen_UART

This sketch shows how to use the Seetron gloSerialOLED macros to
talk to a GLO-216 or GLO-416 serial OLED using an Arduino 
hardware serial port (UART). This program is meant for boards
like the Mega that have more than one hardware UART. 
Sharing the bootloader port is _not_ recommended. 

====================================================================
MACRO(S) DEMONSTRATED: 

gloRecallSavedScreen
gloSaveStartScreen

gloRecallSavedScreen GLO instructions that display the startup 
screen stored in flash memory. 

gloSaveStartScreen GLO instructions that store a startup screen 
to flash. The stored data includes text _and_ instructions 
received since the most-recent clear-screen. This allows you to 
embed default instructions (e.g., font size) into your startup 
screen.
====================================================================
Connections:
GLO +5 to Arduino +5V
GLO GND to Arduino GND
GLO SER to Arduino pin TX1
GLO SPOL jumper: Cut
____________
History:
1st Release 2 June 2014
(Tested under IDE version 1.5.6-r2 w/ Arduino MEGA 2560, Arduino UNO)
____________
More Info:
seetron.com or email tech@seetron.com
*/
// Include SoftwareSerial 
#include <SoftwareSerial.h>

// Include gloSerialOLED _and_ the 'streaming' template, which lets you combine 
// multiple print()s into a single line. This is required by the serial OLED macros. 
#include <gloSerialOLED.h>
gloStreamingTemplate

// Initialize SoftwareSerial by naming the serial object, and
// specifying the output pin and serial polarity (SPOL).
// If the SPOL jumper on the GLO is intact, use "inverted."
// If SPOL is cut, use "noninverted."

gloSoftSerialSetup( myOLED, 3, noninverted );

// Note that this is _outside_ of the standard Arduino setup
// and loop blocks. This makes the serial object visible/usable
// globally--in both setup() and loop().

//===================================================================
void setup() {
// Begin using the serial object created above.
  gloSoftSerialBegin( myOLED ) ;
  
// Allow 1/4 sec for the OLED to start up. 
  delay(250) ; 

// Clear the screen, display demo title in 2x height font.
  myOLED << gloClear << gloFont_1w2h << " Startup Screen" ;  
  delay(1000) ;

// For kicks, wipe the demo message off...
  for (byte i=0; i<16; i++) {
   myOLED << gloSetPosition( i ) << "|" ;
   delay( 50 ); 
  }

// Now recall the startup screen from memory
  myOLED << gloRecallSavedScreen ;
  
  delay(1000) ;
  
/* We don't want to mess up your startup screen, so this demo 
   does not actually save a screen. But if you want to, 
   you can uncomment the line Serial1 << gloSaveStartScreen ;
   to memorize the official Acme startup screen. 
   
   NOTE: To prevent erasure/replacement of a startup screen, 
   CUT the jumper marked DSU on the GLO pcb. This write-
   protects the startup screen and custom chars stored in 
   flash. */
   
   myOLED << gloClear << gloFont_2w2h << "ACME" ;
   myOLED << gloFont_1w1h << gloSetCursor(9,0) << "Rocket" ;
   myOLED << gloSetCursor(9,1) << "Skates"; 

//  myOLED << gloSaveStartScreen ;   // < Uncomment to replace start screen
}

//===================================================================
/*   */ 
void loop() {

}
