/* ===================================================================
   HELPFUL MACROS FOR USING GLO-216 AND GLO-416 SERIAL OLEDS
            v0.1 02 June 2014, tech@seetron.com
			
	This set of macros simplifies the job of writing Arduino 
	programs to drive seetron.com's GLO-216 and -416 serial OLEDs.
	
	-NOTE: There is no accompanying .cpp file. These are purely 
	macros that help write your Arduino code.  */

/* ------------------------------------------------------------------- 
  Streaming-Style Serial Printing  
NOTE: The streaming template below must be placed directly in your 
sketch by putting gloStreamingTemplate right after #include-ing this
file. (The different build sequences for some of the various boards 
generated errors when the template was directly included here.) */

#define gloStreamingTemplate template<class T> inline Print &operator <<(Print &obj, T arg) { obj.print(arg); return obj; }

/* -------------------------------------------------------------------
  Software Serial Setup */

#define inverted 1
#define spolUncut 1
#define noninverted 0
#define spolCut 0

//Create serial object with pin and polarity.
#define gloSoftSerialSetup( objName,outPin,sPol ) \
SoftwareSerial objName =  SoftwareSerial(255, outPin, sPol); 

#define gloSoftSerialBegin( objName ) \
objName.begin(9600) ;\
objName.write("\xff") ;

/* ------------------------------------------------------------------- 
  GLO-216/416 Control Codes  */

//Move the printing position to the 1st character of the 1st line. 
#define ctrlA "\x01"
#define gloHome "\x01" 

//Increment the font size. 
#define ctrlB "\x02" 
#define gloFontIncr "\x02"

//Reset the font size to smallest. 
#define ctrlC "\x03" 
#define gloFontReset "\x03"

//Set the font size to _w(idth) and _h(eight).
#define gloFont_1w1h "\x03"
#define gloFont_1w2h "\x03\x02"
#define gloFont_2w1h "\x03\x02\x02"
#define gloFont_2w2h "\x03\x02\x02\x02"
#define gloFont_2w4h "\x03\x02\x02\x02\x02"
#define gloFont_4w4h "\x03\x02\x02\x02\x02\x02"

//Backspace: back up one char and erase.
#define ctrlH "\x08" 
#define gloBackspace "\x08"

//Horizontal tab: advance 4 character spaces. 
#define ctrlI "\x09"
#define gloHTab "\x09"

//Linefeed: drop down to next line, same column. 
#define ctrlJ "\x0A"
#define gloLinefeed "\x0A"
#define gloLF "\x0A"

//Vertical tab: jump up to line above, same column. 
#define ctrlK "\x0B"
#define gloVTab "\x0B"

//Clear screen; mark start of screen to save. 
#define ctrlL "\x0C"
#define gloClearScreen "\x0C"
#define gloClear "\x0C"
#define gloCLS "\x0C"

//Carriage return: go to 1st column of next line. 
#define ctrlM "\x0D"
#define gloReturn "\x0D"
#define gloCR "\x0D"

//Turn on OLED driver.
#define ctrlN "\x0E"
#define gloDriverOn "\x0E"

//Turn off OLED driver (dims screen).
#define ctrlO "\x0F"
#define gloDriverOff "\x0F"

//Set the next printing position.
#define ctrlP "\x10"
#define gloSetPosition( charLoc ) "\x10" << (char) ( charLoc + 64 )
#define gloSetCursor( col,row ) "\x10" << (char) ( col + (row * 16)  + 64 )
#define gloSetRowCol( row,col ) "\x10" << (char) ( col + (row * 16)  + 64 )

//Accept 2 to 8 characters to be printed with right-alignment. 
#define ctrlR "\x12"
#define gloRightAlign( width ) "\x12" << (char) ( width + '0' )

//Set the printing position _and_ right-align text. 
 
#define gloRightAlignAt( charLoc, width ) "\x10" << (char) ( charLoc + 64 ) << "\x12"  << (char) ( width + '0' )
#define gloSetCursorAlignRight( col, row, width ) "\x10" << (char) ( col + (row * 16)  + 64 ) << "\x12" << (char) ( width + '0' )

//Set numbers displayed at full screen height to use 7-segment patterns. 
#define ctrlS "\x13"
#define glo7SegNums "\x13"

//Set numbers displayed at full screen height to use normal text-style bitmaps. 
#define ctrlT "\x14"
#define gloTextNums "\x14"

//Begin multipart instruction. 
#define gloESC "\x1B"
#define gloEscape "\x1B"

//Display one of the custom characters, 0-15. 
#define gloCustomChar( ccnum ) (char) ( ccnum + 0x80 )

/* ------------------------------------------------------------------- 
  GLO-216/416 Escape Sequences */

//Create a custom character (0-15). Patarray is an 8-byte array, such as: 
// byte smiley[8] = { 0x00,0x11,0x04,0x00,0x11,0x0E,0x00,0x00 };
#define gloCreateChar( ccnum, patarray ) "\x1B" << (char) ( ((ccnum /8 ) * 0x20) + 'D' ) \
<< (char) ((ccnum % 8) + '0') \
<< (char) patarray[0] << (char) patarray[1] << (char) patarray[2] << (char) patarray[3] \
<< (char) patarray[4] << (char) patarray[5] << (char) patarray[6] << (char) patarray[7]

//Save to flash all text & instructions starting with the first byte 
// after the most recent clear-screen. 
#define gloSaveStartScreen "\x1B\x58\x30"

//Recall the startup screen from flash memory. 
#define gloRecallSavedScreen "\x0C\x03\x1B\x45\x30"

//Save the current custom characters to flash memory. 
#define gloSaveCustomChars "\x1B\x78\x30"

//Recall custom characters from flash memory. 
#define gloRecallCustomChars "\x1B\x65\x30"



